@@ -35,22 +35,20 @@ class DBText:
         self.iscreated = master_connection is not None
         self.isconnected = False
         self.startrv = ""
-
-        
-    def get_create_db_args(self, **kw):
-        return ""
-        
-    def create(self, sqlfile=None, encoding=None, tables_dir=None, **kw):
         try:
             self.cnxn = self.master_connection or self.make_connection("master")
             self.isconnected = True
         except pyodbc.Error as e:
             self.logger.error(f"Unexpected error opening connection to db {self.database_name}: %s", e)
             raise
+        
+    def get_create_db_args(self, **kw):
+        return ""
+        
+    def create(self, sqlfile=None, encoding=None, tables_dir=None, **kw):
         self.create_empty_db(**kw)
         self.populate_empty_db(sqlfile, tables_dir, encoding)
 
-
     def create_empty_db(self, **kw):
         try:
             attachsql = "CREATE DATABASE " + self.quote(self.database_name) + self.get_create_db_args(**kw) + ";"
@@ -455,13 +453,13 @@ class DBText:
                     
     def write_all_tables(self, table_file_pattern, blob_pattern, ttcxn, exclude=""):
         for tablename in self.expand_table_names(ttcxn, "*", exclude):
-            self.logger.debug("Making file for table", repr(tablename))
+            self.logger.debug("Making file for table %s", repr(tablename))
             self.dumptable(ttcxn, tablename, "", table_file_pattern, blob_pattern)
 
     def write_data(self, writeDir, use_master_connection=False, json_format=False, **kw):
         table_file_pattern, blob_pattern = self.make_empty_tables_dir(writeDir, json_format)
         if use_master_connection:
-            self.write_all_tables(table_file_pattern, blob_pattern, self.cnxn, **kw)
+            self.write_all_tables(table_file_pattern, blob_pattern, self.master_connection, **kw)
         else:
             with self.make_connection(self.database_name) as ttcxn:
                 self.write_all_tables(table_file_pattern, blob_pattern, ttcxn, **kw)
@@ -492,7 +490,7 @@ class DBText:
         return []
 
     def dumptables(self, sut_ext, table_str, usemaxcol='rv', exclude="", dumpwholenamestr="", dumpableBlobs=True):
-        if not self.isconnected:
+        if not self.iscreated:
             self.logger.info(f"unable to dump tables for {self.database_name}, it is not created yet.")
             return
         dumpwholenames = dumpwholenamestr.split(',')
@@ -555,7 +553,7 @@ class DBText:
         return table_data
 
     def dumpchanges(self, table_fn_pattern, tables_dir=None, exclude=""):
-        if not self.isconnected:
+        if not self.iscreated:
             self.logger.info(f"unable to dump tables for {self.database_name}, it is not created yet.")
             return
         tables_dir = tables_dir or self.get_tables_dir_name()
